pitchtools.diatonic_pitch_name_to_chromatic_pitch_name
======================================================

.. autofunction:: abjad.tools.pitchtools.diatonic_pitch_name_to_chromatic_pitch_name.diatonic_pitch_name_to_chromatic_pitch_name
